@@ -18,22 +18,10 @@
 use strict;
 use warnings;
 
-use Cwd qw( abs_path );
+use FindBin;
+use lib "$FindBin::Bin/../lib";
 
-our ($prog_name, $prog_dir, $base_dir);
-
-BEGIN {
-   $ENV{PATH} = "/usr/bin:/bin:/usr/sbin:/sbin:$ENV{PATH}";
-
-   $prog_name = $0;                    ## prog name
-   $prog_name =~ s{^.*[\\/]}{}g;
-   $prog_dir  = abs_path($0);          ## prog dir
-   $prog_dir  =~ s{[\\/][^\\/]*$}{};
-   $base_dir  = $prog_dir;             ## base dir
-   $base_dir  =~ s{[\\/][^\\/]*$}{};
-
-   unshift @INC, "$base_dir/lib";
-}
+my $prog_name = $0; $prog_name =~ s{^.*[\\/]}{}g;
 
 use Time::HiRes qw(time);
 use MCE;
@@ -80,7 +68,6 @@ my $mce = MCE->new(
    chunk_size  => $chunk_size
 );
 
-$mce->spawn();
 $start = time();
 
 ## Below, $chunk_ref is a reference to an array containing the next
@@ -99,7 +86,6 @@ $mce->forchunk(\@input_data, sub {
 });
 
 $end = time();
-$mce->shutdown();
 
 printf STDERR "\n## Compute time: %0.03f\n\n",  $end - $start;
 
